<?php
/**
 * Claremont Theme Customizer.
 *
 * @package Claremont
 */

//SANITIZATION FUNCTIONS
function claremont_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}

function claremont_sanitize_choices( $input, $setting ) {
    global $wp_customize;
 
    $control = $wp_customize->get_control( $setting->id );
 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function claremont_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
        return 1;
    } else {
        return '';
    }
}

function claremont_sanitize_hex_rgb_rgba_color( $input ) {

    if ( '' === $input ) {
        return '';
    }

    if (
    	preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $input )
    	|| preg_match('/\A^rgb\(([0]*[0-9]{1,2}|[1][0-9]{2}|[2][0-4][0-9]|[2][5][0-5])\s*,\s*([0]*[0-9]{1,2}|[1][0-9]{2}|[2][0-4][0-9]|[2][5][0-5])\s*,\s*([0]*[0-9]{1,2}|[1][0-9]{2}|[2][0-4][0-9]|[2][5][0-5])\s*,\s*([0-9]*\.?[0-9]+)\)$\z/im', $input)
    	|| preg_match('/\A^rgba\(([0]*[0-9]{1,2}|[1][0-9]{2}|[2][0-4][0-9]|[2][5][0-5])\s*,\s*([0]*[0-9]{1,2}|[1][0-9]{2}|[2][0-4][0-9]|[2][5][0-5])\s*,\s*([0]*[0-9]{1,2}|[1][0-9]{2}|[2][0-4][0-9]|[2][5][0-5])\s*,\s*([0-9]*\.?[0-9]+)\)$\z/im', $input)
    	) {
        return $input;
    }

}

/**
 * Add postMessage support for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function claremont_customize_register( $wp_customize ) {

	// WordPress sections, controls and settings
	$wp_customize->get_control( 'blogname' )->section = 'title_tagline';
	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_control( 'blogdescription' )->section = 'title_tagline';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	// Setting - Logo/Site Title Width
	$wp_customize->add_setting( 'logo_width', array(
		'default'           => 24,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control(
			'logo_width',
			array(
				'settings'		=> 'logo_width',
				'section'		=> 'title_tagline',
				'label'			=> esc_html__('Logo/Site Title Width (%)', 'claremont'),
				'description'   => esc_html__('For large screens, default width is 24%. The CTA button area and tagline area will resize as appropriate.', 'claremont'),
				'priority'		=> 9,
				'type'       	=> 'number',
				'input_attrs' => array(
                'min'   => 10,
                'max'   => 75,
                'step'  => 1,
            ),
			)
	);

	// Setting - Phone Text
	$wp_customize->add_setting(
		'claremont_tel_text',
		array(
			'default'			=> esc_html__( 'Enter your phone lead-in here', 'claremont' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'claremont_sanitize_text',
		)
	);
	$wp_customize->add_control(
		'claremont_tel_text',
		array(
			'settings'		=> 'claremont_tel_text',
			'section'		=> 'title_tagline',
			'type'			=> 'text',
			'label'			=> esc_html__( 'Phone Title', 'claremont' )
		)
	);

	// Setting - Phone Number
	$wp_customize->add_setting(
		'claremont_tel_num',
		array(
			'default'			=> esc_html__( 'Phone number', 'claremont' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'claremont_sanitize_text',
		)
	);
	$wp_customize->add_control(
		'claremont_tel_num',
		array(
			'settings'		=> 'claremont_tel_num',
			'section'		=> 'title_tagline',
			'type'			=> 'text',
			'label'			=> esc_html__( 'Phone Number', 'claremont' )
		)
	);

	// Setting - Header Button
	$wp_customize->add_setting(
		'claremont_top_btn',
		array(
			'default'			=> '',
			'sanitize_callback' => 'absint'
		)
	);
	$wp_customize->add_control(
		'claremont_top_btn',
		array(
			'settings'		=> 'claremont_top_btn',
			'section'		=> 'title_tagline',
			'type'			=> 'dropdown-pages',
			'label'			=> esc_html__( 'Button In Header Link', 'claremont' )
		)
	);

	// Setting - Site Copyright
	$wp_customize->add_setting( 'footer_content' , array(
		'default'			=> '',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'claremont_sanitize_text',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Control( 
		$wp_customize, 
		'footer_content', 
		array(
			'label'    => esc_html__( 'Site Copyright', 'claremont' ),
			'section'  => 'title_tagline',
			'settings' => 'footer_content',
			'type'     => 'textarea',
		) ) 
	);

	// Section - Color Schemes
	$wp_customize->add_section( 'styles_sec' , array(
		'title'      => esc_html__( 'Color Schemes', 'claremont' ),
		'priority'   => 50,
	) );

	// Setting - Choose Style
	$wp_customize->add_setting( 'stylesheet', array(
		'default'           => 'fresh',
		'sanitize_callback' => 'claremont_sanitize_choices',
	) );
	$wp_customize->add_control( 'stylesheet', array(
		'label'   => esc_html__( 'Choose Style', 'claremont' ),
		'type'    => 'select',
		'section' => 'styles_sec',
		'choices' => array(
			'discovery'			=> esc_html__( 'Discovery', 'claremont' ),
			'edge'				=> esc_html__( 'Edge', 'claremont' ),
			'fresh'				=> esc_html__( 'Fresh (Default)', 'claremont' ),
			'grape'				=> esc_html__( 'Grape', 'claremont' ),
			'industry-blue'		=> esc_html__( 'Industry - Blue', 'claremont' ),
			'industry-green'	=> esc_html__( 'Industry - Green', 'claremont' ),
			'industry-red'		=> esc_html__( 'Industry - Red', 'claremont' ),
			'safety'			=> esc_html__( 'Safety', 'claremont' ),
			'slate'				=> esc_html__( 'Slate', 'claremont' ),
		)
	) );

	// Section - Site Options
	$wp_customize->add_section( 'site_options_sec' , array(
		'title'      => esc_html__( 'Site Options', 'claremont' ),
		'priority'   => 20,
	) );

	// Setting - Search icon in navigation
	$wp_customize->add_setting(
		'search_icon',
		array(
			'default'			=> 1,
			'sanitize_callback' => 'claremont_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
		'search_icon',
		array(
			'settings'		=> 'search_icon',
			'section'		=> 'site_options_sec',
			'label'			=> esc_html__( 'Search Icon in Navigation', 'claremont' ),
			'description'	=> esc_html__( 'Display the search function in the main navigation menu bar.', 'claremont' ),
			'type'       	=> 'checkbox',
		)
	);

	// Setting - Content Width
	$wp_customize->add_setting( 'content_width', array(
		'default'           => 1200,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control(
			'content_width',
			array(
				'settings'		=> 'content_width',
				'section'		=> 'site_options_sec',
				'label'			=> esc_html__('Content Width in pixels', 'claremont'),
				'description'   => esc_html__('For large screens, default width is 1200px. For smaller devices, the theme is responsive and the content width will resize as appropriate.', 'claremont'),
				'type'       	=> 'number',
				'input_attrs' => array(
                'min'   => 600,
                'max'   => 1920,
                'step'  => 10,
            ),
			)
	);

	// Setting - Sticky Footer
	$wp_customize->add_setting(
		'sticky_footer',
		array(
			'default'			=> 0,
			'sanitize_callback' => 'absint'
		)
	);
	$wp_customize->add_control(
			'sticky_footer',
			array(
				'settings'		=> 'sticky_footer',
				'section'		=> 'site_options_sec',
				'label'			=> esc_html__( 'Enable Sticky Footer', 'claremont' ),
				'type'       	=> 'checkbox',
			)
	);

	// Section - Typography
	$wp_customize->add_section( 'typography_sec' , array(
		'title'     => esc_html__( 'Typography', 'claremont' ),
		'priority'	=> 50,
	) );

	// Setting - Font
	$wp_customize->add_setting( 'font_style', array(
		'default'           => 'Open Sans',
		'sanitize_callback' => 'claremont_sanitize_choices',
	) );
	$wp_customize->add_control( 'font_style', array(
		'label'   => esc_html__( 'Font', 'claremont' ),
		'type'    => 'select',
		'section' => 'typography_sec',
		'choices' => array(
			'Abel' => 'Abel',
			'Alegreya Sans'	=> 'Alegreya Sans',
			'Arimo'	=> 'Arimo',
			'Arvo' => 'Arvo',
			'Asap' => 'Asap',
			'Bitter' => 'Bitter',
			'Bree Serif' => 'Bree Serif',
			'Cabin'	=> 'Cabin',
			'Catamaran'	=> 'Catamaran',
			'Crimson Text' => 'Crimson Text',
			'Cuprum' => 'Cuprum',
			'Dosis'	=> 'Dosis',
			'Droid Sans' => 'Droid Sans',
			'Droid Serif' => 'Droid Serif',
			'Exo' => 'Exo',
			'Exo 2'	=> 'Exo 2',
			'Fjalla One' => 'Fjalla One',
			'Hind' => 'Hind',
			'Inconsolata' => 'Inconsolata',
			'Josefin Sans' => 'Josefin Sans',
			'Karla'	=> 'Karla',
			'Lato' => 'Lato',
			'Lora' => 'Lora',
			'Maven Pro'	=> 'Maven Pro',
			'Merriweather' => 'Merriweather',
			'Merriweather Sans'	=> 'Merriweather Sans',
			'Montserrat' => 'Montserrat',
			'Muli' => 'Muli',
			'Noto Sans'	=> 'Noto Sans',
			'Noto Serif' => 'Noto Serif',
			'Nunito' => 'Nunito',
			'Open Sans'	=> 'Open Sans',
			'Orbitron' => 'Orbitron',
			'Oswald' => 'Oswald',
			'Oxygen' => 'Oxygen',
			'Passion One' => 'Passion One',
			'Play' => 'Play',
			'Playfair Display' => 'Playfair Display',			
			'Poppins' => 'Poppins',
			'PT Sans' => 'PT Sans',
			'PT Serif' => 'PT Serif',
			'Raleway' => 'Raleway',
			'Roboto' => 'Roboto',
			'Roboto Slab' => 'Roboto Slab',
			'Rubik'	=> 'Rubik',
			'Signika' => 'Signika',
			'Source Sans Pro' => 'Source Sans Pro',
			'Titillium Web'	=> 'Titillium Web',
			'Ubuntu' => 'Ubuntu',
			'Vollkorn' => 'Vollkorn',
			'Yanone Kaffeesatz'	=> 'Yanone Kaffeesatz',
		)
	) );

	// Section - Blog Settings
	$wp_customize->add_section( 'blog_layout_sec' , array(
		'title'      => esc_html__( 'Blog Settings', 'claremont' ),
		'priority'   => 50,
	) );

	// Setting - Sidebar position
	$wp_customize->add_setting( 'blog_layout', array(
		'default'           => '',
		'sanitize_callback' => 'claremont_sanitize_choices',
	) );
	$wp_customize->add_control( 'blog_layout', array(
		'label'   => esc_html__( 'Blog Sidebar Position', 'claremont' ),
		'description'   => esc_html__( 'Page sidebar position can be edited for each page individually.', 'claremont' ),
		'type'    => 'select',
		'section' => 'blog_layout_sec',
		'choices' => array(
			'left-sidebar'  => esc_html__( 'Left Sidebar', 'claremont' ),
			''    => esc_html__( 'No Sidebar', 'claremont' ),
			'right-sidebar' => esc_html__( 'Right Sidebar', 'claremont' ),
		)
	) );

	// Setting - Blog - author on/off
	$wp_customize->add_setting(
		'show_author',
		array(
			'default'			=> 1,
			'sanitize_callback' => 'claremont_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
			'show_author',
			array(
				'settings'		=> 'show_author',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__( 'Display Author in Blog Posts', 'claremont' ),
				'type'       	=> 'checkbox',
			)
	);

	// Setting - Blog - date on/off
	$wp_customize->add_setting(
		'show_date',
		array(
			'default'			=> 1,
			'sanitize_callback' => 'claremont_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
			'show_date',
			array(
				'settings'		=> 'show_date',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__( 'Display Date in Blog Posts', 'claremont' ),
				'type'       	=> 'checkbox',
			)
	);

	// Setting - Blog - trim content on/off
	$wp_customize->add_setting(
		'trim_content',
		array(
			'default'			=> 0,
			'sanitize_callback' => 'claremont_sanitize_checkbox'
		)
	);
	$wp_customize->add_control(
			'trim_content',
			array(
				'settings'		=> 'trim_content',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__( 'Trim Blog Post Content (blog index/archive/search)', 'claremont' ),
				'type'       	=> 'checkbox',
			)
	);

	// Setting - Blog - trim content length
	$wp_customize->add_setting(
		'trim_content_words',
		array(
			'default'			=> '70',
			'sanitize_callback' => 'absint'
		)
	);
	$wp_customize->add_control(
			'trim_content_words',
			array(
				'settings'		=> 'trim_content_words',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__('Trim Post Content By:', 'claremont'),
				'description'   => esc_html__('Default is first 70 words.', 'claremont'),
				'type'       	=> 'number',
				'active_callback' => 'callback_trim_content',
				'input_attrs' => array(
                'min'   => 5,
                'max'   => 300,
                'step'  => 1,
            ),
			)
	);
	$wp_customize->get_control( 'trim_content_words' )->active_callback = 'callback_trim_content';
	function callback_trim_content( $control ) {
		if ( $control->manager->get_setting( 'trim_content' )->value() == 1 ) {
			return true;
		} else {
			return false;
		}
	}

	// Setting - Gallery Image Padding
	$wp_customize->add_setting( 'gallery_padding', array(
		'default'           => 2,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control(
			'gallery_padding',
			array(
				'settings'		=> 'gallery_padding',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__('Gallery Image Padding', 'claremont'),
				'type'       	=> 'number',
				'input_attrs' => array(
                'min'   => 0,
                'max'   => 10,
                'step'  => 1,
            ),
			)
	);

	// Setting - Gallery Image Margin
	$wp_customize->add_setting( 'gallery_margin', array(
		'default'           => 4,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control(
			'gallery_margin',
			array(
				'settings'		=> 'gallery_margin',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__('Gallery Image Margin', 'claremont'),
				'type'       	=> 'number',
				'input_attrs' => array(
                'min'   => 0,
                'max'   => 10,
                'step'  => 1,
            ),
			)
	);

	// Setting - Gallery Image Border Size
	$wp_customize->add_setting( 'gallery_border_size', array(
		'default'           => 2,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control(
			'gallery_border_size',
			array(
				'settings'		=> 'gallery_border_size',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__('Gallery Image Border Size', 'claremont'),
				'type'       	=> 'number',
				'input_attrs' => array(
                'min'   => 0,
                'max'   => 10,
                'step'  => 1,
            ),
			)
	);

	// Setting - Gallery Image Border Radius
	$wp_customize->add_setting( 'gallery_border_radius', array(
		'default'           => 3,
		'sanitize_callback' => 'absint',
	) );
	$wp_customize->add_control(
			'gallery_border_radius',
			array(
				'settings'		=> 'gallery_border_radius',
				'section'		=> 'blog_layout_sec',
				'label'			=> esc_html__('Gallery Image Border Radius', 'claremont'),
				'type'       	=> 'number',
				'input_attrs' => array(
                'min'   => 0,
                'max'   => 10,
                'step'  => 1,
            ),
			)
	);

    // Setting - Gallery Image Background Color
    $wp_customize->add_setting(
        'gallery_bg_color',
        array(
            'default'			=> 'rgba(0,0,0,0)',
            'transport'			=> 'postMessage',
            'sanitize_callback' => 'claremont_sanitize_hex_rgb_rgba_color',
        )
    );
    $wp_customize->add_control(
        new Claremont_Alpha_Color_Control(
            $wp_customize,
            'gallery_bg_color',
            array(
                'label'         => esc_html__( 'Gallery Image Background Color', 'claremont' ),
                'section'       => 'blog_layout_sec',
                'settings'      => 'gallery_bg_color',
                'show_opacity'  => true,
                'palette'   => array(
                    '#000000',
                    '#ffffff',
                    '#dd3333',
                    '#dd9933',
                    '#eeee22',
                    '#81d742',
                    '#1e73be',
                    '#8224e3',
                )
            )
        )
    );

	// Setting - Gallery Image Border Color
	$wp_customize->add_setting( 'gallery_border_color' , array(
		'default'           => '#f5f5f5',
		'transport'			=> 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'gallery_border_color', 
		array(
			'label'    => esc_html__( 'Gallery Image Border Color', 'claremont' ),
			'section'  => 'blog_layout_sec',
			'settings' => 'gallery_border_color',
		) ) 
	);

	// Section - Theme Information
	$wp_customize->add_section( 'theme_info_sec' , array(
		'title'      => esc_html__( 'Theme Help', 'claremont' ),
		'priority'   => 200,
		'description' => esc_html__('For help with Claremont, please see the theme documentation.', 'claremont' ),
	) );
	$wp_customize->add_control(
		new Claremont_Customize_Extra_Control(
			$wp_customize,
			'theme_docs',
			array(
				'section'   => 'theme_info_sec',
				'type'      => 'docs',
				'label'		=> esc_html__( 'Documentation','claremont' ),
				'url'		=> 'https://uxlthemes.com/docs/claremont-theme/',
				'priority'	=> 10
			)
		)
	);

	// Section - Go Pro
	$wp_customize->add_section( 'go_pro_sec' , array(
		'title'      => esc_html__( 'Go Pro', 'claremont' ),
		'priority'   => 1,
		'description' => esc_html__( 'Upgrade to Claremont Pro for even more cool features and customization options.', 'claremont' ),
	) );
	$wp_customize->add_control(
		new Claremont_Customize_Extra_Control(
			$wp_customize,
			'go_pro',
			array(
				'section'   => 'go_pro_sec',
				'type'      => 'pro-link',
				'label'		=> esc_html__( 'Go Pro', 'claremont' ),
				'url'		=> 'https://uxlthemes.com/theme/claremont-pro/',
				'priority'	=> 10
			)
		)
	);

}
add_action( 'customize_register', 'claremont_customize_register' );

/**
 * Customized styling
 */
if ( ! function_exists( 'claremont_custom_css' ) ) {
	function claremont_custom_css( $css = array() ) {

		$font_style = get_theme_mod( 'font_style', 'Open Sans' );
		if ($font_style && $font_style != "Open Sans") {
			$css[] = 'body, button, input, select, textarea { font: 400 16px/1.625 "' . esc_html( $font_style ) . '", Arial, Helvetica, sans-serif; } .site-main{font-family: "' . esc_html( $font_style ) . '", Arial, Helvetica, sans-serif; } ';
		}

		$content_width = get_theme_mod( 'content_width' );
		if ($content_width && $content_width != "1200") {
			$css[] = '.container { max-width: ' . esc_attr($content_width) . 'px; } ';
		}

		$logo_width = get_theme_mod( 'logo_width' );
		if ($logo_width && $logo_width != "0" && $logo_width != "24") {
			if ($logo_width > 99) {
				$logo_width = 99;
			}
			if ($logo_width < 1) {
				$logo_width = 1;
			}
			$top_right_76_width = 100 - $logo_width;
			$cta_width = round( (100 - $logo_width) * 0.43, 1 );
			$top_right_width = 100 - $cta_width - $logo_width;
			$css[] = '@media screen and (min-width: 1025px) { .top-logo {width: ' . esc_attr($logo_width) . '%;}.top-cta {width: ' . esc_attr($cta_width) . '%;}.top-right {width: ' . esc_attr($top_right_width) . '%;}.top-right-76 {width: ' . esc_attr($top_right_76_width) . '%;} } ';
		}

		$gallery_padding = get_theme_mod( 'gallery_padding', '2' );
		if ($gallery_padding && $gallery_padding != "2") {
			$css[] = '.gallery .gallery-item { padding: ' . esc_attr($gallery_padding) . 'px; } ';
		}

		$gallery_margin = get_theme_mod( 'gallery_margin', '4' );
		if ($gallery_margin && $gallery_margin != "4") {
			$css[] = '.gallery .gallery-item { margin: 0 ' . esc_attr($gallery_margin) . 'px ' . esc_attr($gallery_margin) . 'px 0; } ';
		}

		$gallery_border_size = get_theme_mod( 'gallery_border_size', '2' );
		if ($gallery_border_size && $gallery_border_size != "2") {
			$css[] = '.gallery .gallery-item { border-width: ' . esc_attr($gallery_border_size) . 'px; } ';
		}

		$gallery_border_radius = get_theme_mod( 'gallery_border_radius', '3' );
		if ($gallery_border_radius && $gallery_border_radius != "3") {
			$css[] = '.gallery .gallery-item, .gallery .gallery-item img { border-radius: ' . esc_attr($gallery_border_radius) . 'px; } ';
		}

		$gallery_bg_color = get_theme_mod( 'gallery_bg_color', 'rgba(0,0,0,0)' );
		if ($gallery_bg_color && $gallery_bg_color != "rgba(0,0,0,0)") {
			$css[] = '.gallery .gallery-item { background: ' . esc_attr($gallery_bg_color) . '; } ';
		}

		$gallery_border_color = get_theme_mod( 'gallery_border_color', '#f5f5f5' );
		if ($gallery_border_color && $gallery_border_color != "#f5f5f5") {
			$css[] = '.gallery .gallery-item { border-color: ' . esc_attr($gallery_border_color) . '; } ';
		}

		return implode( '', $css );

	}
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function claremont_customize_preview() {
	wp_enqueue_script( 'claremont-customizer-preview', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '', true );
}
add_action( 'customize_preview_init', 'claremont_customize_preview' );


function claremont_customizer_script() {
	wp_enqueue_script('claremont-customizer-script', get_template_directory_uri() .'/functions/js/customizer-scripts.js', array("jquery"),'', true  );
	wp_enqueue_style('claremont-customizer-style', get_template_directory_uri() .'/functions/css/customizer-style.css');	
}
add_action('customize_controls_enqueue_scripts', 'claremont_customizer_script');


/**
 * Controls for adding extra information to a Customizer section.
 */
if ( class_exists( 'WP_Customize_Control' ) ) {

	class Claremont_Customize_Extra_Control extends WP_Customize_Control {
		public $settings = 'blogname';
		public $description = '';
		public $url = '';
		public $group = '';

		public function render_content() {
			switch ( $this->type ) {
				default:
				case 'text' :
					echo '<p class="description">' . $this->description . '</p>';
					break;

				case 'docs':
				echo sprintf(
							'<a href="%1$s" class="button-primary" target="_blank">%2$s</a>',
							esc_url( $this->url ),
							esc_html__( 'Documentation', 'claremont' )
						);
					break;

				case 'pro-link':
				echo sprintf(
							'<a href="%1$s" class="button-primary" target="_blank">%2$s</a>',
							esc_url( $this->url ),
							esc_html__( 'Go Pro', 'claremont' )
						);
					break;
					
				case 'line' :
					echo '<hr />';
					break;
			}
		}
	}

/**
 * Alpha Color Picker Customizer Control
 *
 * This control adds a second slider for opacity to the stock WordPress color picker,
 * and it includes logic to seamlessly convert between RGBa and Hex color values as
 * opacity is added to or removed from a color.
 *
 * This Alpha Color Picker is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this Alpha Color Picker. If not, see <http://www.gnu.org/licenses/>.
 */
class Claremont_Alpha_Color_Control extends WP_Customize_Control {
	/**
	 * Official control name.
	 */
	public $type = 'alpha-color';
	/**
	 * Add support for palettes to be passed in.
	 *
	 * Supported palette values are true, false, or an array of RGBa and Hex colors.
	 */
	public $palette;
	/**
	 * Add support for showing the opacity value on the slider handle.
	 */
	public $show_opacity;
	/**
	 * Render the control.
	 */
	public function render_content() {
		// Process the palette
		if ( is_array( $this->palette ) ) {
			$palette = implode( '|', $this->palette );
		} else {
			// Default to true
			$palette = ( false === $this->palette || 'false' === $this->palette ) ? 'false' : 'true';
		}
		// Support passing show_opacity as string or boolean. Default to true.
		$show_opacity = ( false === $this->show_opacity || 'false' === $this->show_opacity ) ? 'false' : 'true';
		// Output the label if passed in
		if ( isset( $this->label ) && '' !== $this->label ) {
			echo '<span class="customize-control-title">' . sanitize_text_field( $this->label ) . '</span>';
		}
		// Output the description if passed in	
		if ( isset( $this->description ) && '' !== $this->description ) {
			echo '<span class="description customize-control-description">' . sanitize_text_field( $this->description ) . '</span>';
		} 
		?>
		<div class="customize-control-content">
			<label>
				<input class="alpha-color-control" type="text" data-show-opacity="<?php echo $show_opacity; ?>" data-palette="<?php echo esc_attr( $palette ); ?>" data-default-color="<?php echo esc_attr( $this->settings['default']->default ); ?>" <?php $this->link(); ?>  />
			</label>
		</div>
		<?php
	}
}

}